@@ -23,9 +23,17 @@
 #'   Default is \code{TRUE}.
 #' @return [\code{integer}]. Ids for experiments which match the query.
 #' @export
+#' @examples
+#' reg = makeExperimentRegistry(id="example1", file.dir=tempfile())
+#' p1 = addProblem(reg, "one", 1)
+#' p2 = addProblem(reg, "two", 2)
+#' a = addAlgorithm(reg, "A", fun=function(static, n) static + n)
+#' addExperiments(reg, algo.design=makeDesign(a, exhaustive = list(n = 1:4)))
+#' findExperiments(reg, prob.pattern="one")
+#' findExperiments(reg, prob.pattern="o")
+#' findExperiments(reg, algo.pars = (n > 2))
 findExperiments = function(reg, ids, prob.pattern, prob.pars, algo.pattern, algo.pars, repls, match.substring=TRUE) {
   checkExperimentRegistry(reg, strict=TRUE)
-  BatchJobs:::syncRegistry(reg)
   if (!missing(prob.pattern))
     checkArg(prob.pattern, "character", len=1L, na.ok=FALSE)
   if (!missing(algo.pattern))
